==> export-cis-2014.10-sources.jar: com/xebialabs/xlplatform/extensions/exportcis/route/ExportCisRoute.scala <==
package com.xebialabs.xlplatform.extensions.exportcis.route

import com.typesafe.config.ConfigFactory
import com.xebialabs.deployit.repository.RepositoryServiceHolder.getRepositoryService
import com.xebialabs.xlplatform.endpoints.AuthenticatedData
import com.xebialabs.xlplatform.extensions.exportcis.CisExportSupport
import com.xebialabs.xlplatform.extensions.exportcis.archive.RepositoryExporter.RepositoryRootAlias
import de.schlichtherle.truezip.util.UriDecoder
import grizzled.slf4j.Logging
import spray.http.{HttpResponse, StatusCodes}
import spray.routing.HttpService

import scalax.file.Path

trait ExportCisRoute extends HttpService with Logging with CisExportSupport {

  private val defaultExportDir = ConfigFactory.load("extensions.conf").getString("export-cis.export-dir")

  private val uriDecoder = new UriDecoder()

  val route = (auth: AuthenticatedData) => pathPrefix("export" / "citree") {
    post {
      path(Rest){ ciIdEncoded =>
        rejectNonAdmin(auth) {
          val ciId = uriDecoder.decode(ciIdEncoded)
          parameter('exportDir.?) { exportDirOption =>

            val exportDir = exportDirOption.getOrElse(defaultExportDir)
            logger.info(s"Trying to export CI tree starting from $ciId into $exportDir")
            complete(ciId match {
              case "/" | "" => export(RepositoryRootAlias, Path.fromString(exportDir))(auth)
              case _ if getRepositoryService.exists(ciId) => export(ciId, Path.fromString(exportDir))(auth)
              case _ => HttpResponse(StatusCodes.NotFound, s"CI does not exist [$ciId]")
            })
          }
        }
      }
    }
  }
}

==> export-cis-2015.2.3-sources.jar: com/xebialabs/xlplatform/extensions/exportcis/route/ExportCisRoute.scala <==
package com.xebialabs.xlplatform.extensions.exportcis.route

import com.typesafe.config.ConfigFactory
import com.xebialabs.deployit.repository.RepositoryServiceHolder.getRepositoryService
import com.xebialabs.xlplatform.endpoints.AuthenticatedData
import com.xebialabs.xlplatform.extensions.exportcis.CisExportSupport
import com.xebialabs.xlplatform.extensions.exportcis.archive.RepositoryExporter.RepositoryRootAlias
import de.schlichtherle.truezip.util.UriDecoder
import grizzled.slf4j.Logging
import spray.http.{HttpResponse, StatusCodes}
import spray.routing.HttpService

import scalax.file.Path

trait ExportCisRoute extends HttpService with Logging with CisExportSupport {

  private val defaultExportDir = ConfigFactory.load("extensions.conf").getString("export-cis.export-dir")

  private val uriDecoder = new UriDecoder()

  val route = (auth: AuthenticatedData) => pathPrefix("export" / "citree") {
    post {
      path(Rest){ ciIdEncoded =>
        rejectNonAdmin(auth) {
          val ciId = uriDecoder.decode(ciIdEncoded)
          parameter('exportDir.?(defaultExportDir)) { exportDir =>
            logger.info(s"Trying to export CI tree starting from $ciId into $exportDir")
            complete(ciId match {
              case "/" | "" => export(RepositoryRootAlias, Path.fromString(exportDir))(auth)
              case _ if getRepositoryService.exists(ciId) => export(ciId, Path.fromString(exportDir))(auth)
              case _ => HttpResponse(StatusCodes.NotFound, s"CI does not exist [$ciId]")
            })
          }
        }
      }
    }
  }
}
